-- debug_status = 1
debug_mod_name = "HotCraft"
debug_file = debug_mod_name .. "-debug.txt"
require("utils")

--------------------------------------------------------------------------------------
local function init_globals()
	-- initialize or update general globals of the mod
	debug_print( "init_globals" )
end

--------------------------------------------------------------------------------------
local function on_init() 
	-- called once, the first time the mod is loaded on a game (new or existing game)
	debug_print( "on_init" )
	init_globals()
end

script.on_init(on_init)

--------------------------------------------------------------------------------------
local function on_configuration_changed(data)
	-- detect any mod or game version change
	if data.mod_changes ~= nil then
		local changes = data.mod_changes[debug_mod_name]
		if changes ~= nil then
			debug_print( "update mod: ", debug_mod_name, " ", tostring(changes.old_version), " to ", tostring(changes.new_version) )
		
			init_globals()
		end
	end
end

script.on_configuration_changed(on_configuration_changed)

--------------------------------------------------------------------------------------

local function build_recipe(player, name_to_build, n)
	local recipe_to_build

	-- find basic direct recipe if available
	
	recipe_to_build = player.force.recipes[name_to_build]
	
	if recipe_to_build == nil then
		-- try to find an alternate indirect recipe
		
		for _, recipe in pairs(player.force.recipes) do
			local prods = recipe.products
			for _, prod in pairs(prods) do
				if prod.name == name_to_build then
					recipe_to_build = recipe
					break
				end
			end
			
			if recipe_to_build ~= nil then break end
		end
	end
	
	if recipe_to_build ~= nil then 
		local craftable = player.get_craftable_count(recipe_to_build.name)
		debug_print("recipe=", recipe_to_build.name, " craftable=", craftable)
		craftable = math.min(n,craftable)
		if craftable ~= 0 then
			player.begin_crafting({count=craftable, recipe=recipe_to_build, silent=false})
		end
	end

end

--------------------------------------------------------------------------------------

local function hotcraft(player,n)
	local name_to_build = player.cursor_stack.name

	build_recipe(player, name_to_build, n)	
end

--------------------------------------------------------------------------------------

script.on_event(defines.events.on_player_pipette, function(event)
	local player = game.players[event.player_index]

	local name_to_build = event.item.name

	local n = player.get_item_count(name_to_build)
	
	if n == 0 then
		build_recipe(player, name_to_build, 1)	
	end
end)

--------------------------------------------------------------------------------------

local function hotcraft_hotkey_1(event)
	local player = game.players[event.player_index]
	if player.cursor_stack and player.cursor_stack.valid_for_read then
		hotcraft(player,1)
	end
end

local function hotcraft_hotkey_5(event)
	local player = game.players[event.player_index]
	if player.cursor_stack and player.cursor_stack.valid_for_read then
		hotcraft(player,5)
	end
end

local function hotcraft_hotkey_10(event)
	local player = game.players[event.player_index]
	if player.cursor_stack and player.cursor_stack.valid_for_read then
		hotcraft(player,10)
	end
end

script.on_event("hotcraft_hotkey_1", hotcraft_hotkey_1)
script.on_event("hotcraft_hotkey_5", hotcraft_hotkey_5)
script.on_event("hotcraft_hotkey_10", hotcraft_hotkey_10)
